NAME
Astro::Coord::ECI::VSOP87D::Venus - VSOP87D model of the position of Venus
SYNOPSIS
use Astro::Coord::ECI::VSOP87D::Venus;
use Astro::Coord::ECI::Utils qw{ deg2rad };
use POSIX qw{ strftime };
use Time::Local qw{ localtime };
my $station = Astro::Coord::ECI->new(
name => 'White House',
)->geodetic(
deg2rad( 38.899 ), # radians
deg2rad( -77.038 ), # radians
16.68/1000, # Kilometers
);
my $venus = Astro::Coord::ECI::VSOP87D::Venus->new(
station => $station,
);
my $today = timelocal( 0, 0, 0, ( localtime )[ 3 .. 5 ] );
foreach my $item ( $venus->almanac( $today, $today + 86400 ) ) {
local $\ = "\n";
print strftime( '%d-%b-%Y %H:%M:%S', localtime $item->[0] ),
$item->[3];
}
DESCRIPTION
This Perl class computes the position of Venus using the VSOP87D model. It is a subclass of Astro::Coord::ECI::VSOP87D::_Inferior.
METHODS
This class supports no additional public methods.
ATTRIBUTES
This class has no additional attributes.
SEE ALSO
SUPPORT
Support is by the author. Please file bug reports at https://github.com/trwyant/perl-Astro-Coord-ECI-VSOP87D/issues or in electronic mail to the author.
AUTHOR
Thomas R. Wyant, III harryfmudd at comcast dot net
COPYRIGHT AND LICENSE
Copyright (C) 2018-2022, 2024-2026 by Thomas R. Wyant, III
This program is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For more details, see the full text of the licenses in the files LICENSE-Artistic and LICENSE-GPL.
This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose.